@@ -20,9 +20,12 @@ from .._impl import (
     scout_run_api_GetRunByIdRequest as GetRunByIdRequest,
     scout_run_api_GetRunsByAssetRequest as GetRunsByAssetRequest,
     scout_run_api_GetRunsByAssetResponse as GetRunsByAssetResponse,
+    scout_run_api_InequalityOperator as InequalityOperator,
     scout_run_api_Link as Link,
     scout_run_api_LogSetRid as LogSetRid,
     scout_run_api_RefNameAndType as RefNameAndType,
+    scout_run_api_RelativeOrAbsoluteTimestamp as RelativeOrAbsoluteTimestamp,
+    scout_run_api_RelativeOrAbsoluteTimestampVisitor as RelativeOrAbsoluteTimestampVisitor,
     scout_run_api_Run as Run,
     scout_run_api_RunDataReviewEvaluationStatus as RunDataReviewEvaluationStatus,
     scout_run_api_RunDataReviewSummary as RunDataReviewSummary,
@@ -44,6 +47,7 @@ from .._impl import (
     scout_run_api_SortOptions as SortOptions,
     scout_run_api_SortProperty as SortProperty,
     scout_run_api_TimeRangeFilter as TimeRangeFilter,
+    scout_run_api_TimestampCondition as TimestampCondition,
     scout_run_api_UnarchiveRunsRequest as UnarchiveRunsRequest,
     scout_run_api_Unit as Unit,
     scout_run_api_UpdateAttachmentsRequest as UpdateAttachmentsRequest,
@@ -73,9 +77,12 @@ __all__ = [
     'GetRunByIdRequest',
     'GetRunsByAssetRequest',
     'GetRunsByAssetResponse',
+    'InequalityOperator',
     'Link',
     'LogSetRid',
     'RefNameAndType',
+    'RelativeOrAbsoluteTimestamp',
+    'RelativeOrAbsoluteTimestampVisitor',
     'Run',
     'RunDataReviewEvaluationStatus',
     'RunDataReviewSummary',
@@ -97,6 +104,7 @@ __all__ = [
     'SortOptions',
     'SortProperty',
     'TimeRangeFilter',
+    'TimestampCondition',
     'UnarchiveRunsRequest',
     'Unit',
     'UpdateAttachmentsRequest',
